AUTHORS
=======

* Chris Glass (chrisglass)

CONTRIBUTORS
============

* fivethreeo
* Jonas Obrist
* Issac Kelly
* Audrey Roy
* Martin Brochhaus
* Raúl Cumplido
* Bojan Mihelac
* Rolo Mawlabaux
* Justin Steward 

TRANSLATORS
===========

* Pedro Gracia (Spanish)
